{% extends "@FerienpassAdmin/page/tools/_settings.html.twig" %}
{% trans_default_domain 'admin' %}


{% set translationPrefix = app.request.get('_route')|split('_')[1] %}
{% set action = (app.request.get('_route')|split('.')|first)|split('_')[2] %}

{% block main %}

    <twig:Admin:Edit:AccessCodeStrategy
            class="border-t border-gray-200 dark:border-gray-800 mt-6 pt-6"
            form="{{ form }}"
            formOptions="{{ formOptions }}"
            item="{{ item }}"
            sections="{{ formScreen.sections }}"
            section="{{ section }}"
    />

{% endblock %}
