{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}


{% block main %}

    <div class="relative">

        <div>
                <twig:Admin:Edition:Header edition="{{ edition }}"/>

            <div class="mb-6 flex items-center">
                <twig:Admin:Button
                   href="{{ path('admin_offers_bulk_status', { alias: edition.alias }) }}"
                   data-turbo-frame="modal"
                   class="mr-4">
                    Alle Angebote freigeben...
                </twig:Admin:Button>
                <span class="isolate inline-flex rounded-md shadow-sm">
                    <a href="{{ path(app.current_route, app.current_route_parameters|merge(app.request.query.all)|merge({format: 'web-details'})) }}"
                            class="relative inline-flex items-center rounded-l-md bg-white dark:bg-gray-800 px-3 py-1.5 text-sm font-semibold text-gray-900 dark:text-gray-100 ring-1 ring-inset ring-gray-300 dark:ring-gray-700 hover:bg-gray-50 dark:hover:bg-gray-700 focus:z-10">
                        Detailansicht (Web)
                    </a>
                    <a href="{{ path(app.current_route, app.current_route_parameters|merge(app.request.query.all)|merge({format: 'web-list'})) }}"
                            class="relative -ml-px inline-flex items-center bg-white dark:bg-gray-800 px-3 py-1.5 text-sm font-semibold text-gray-900 dark:text-gray-100 ring-1 ring-inset ring-gray-300 dark:ring-gray-700 hover:bg-gray-50 dark:hover:bg-gray-700 focus:z-10">
                        Listenansicht (Web)
                    </a>
                    {% for pdf in pdfs %}
                    <a href="{{ path(app.current_route, app.current_route_parameters|merge(app.request.query.all)|merge({format: pdf~'.pdf'})) }}"
                            class="relative -ml-px inline-flex items-center rounded-r-md bg-white dark:bg-gray-800 px-3 py-1.5 text-sm font-semibold text-gray-900 dark:text-gray-100 ring-1 ring-inset ring-gray-300 dark:ring-gray-700 hover:bg-gray-50 dark:hover:bg-gray-700 focus:z-10">
                        {{ "#{pdf}.pdf.0"|trans([], 'export') }}
                    </a>
                    {% endfor %}
                </span>
            </div>

            <twig:Admin:OffersReview edition="{{ edition }}"/>

        </div>
    </div>

{% endblock %}
