<?php

declare(strict_types=1);

namespace Ferienpass\AdminBundle\Tests\Message;

use Ferienpass\AdminBundle\Message\HostInvited;
use PHPUnit\Framework\TestCase;

final class HostInvitedTest extends TestCase
{
    public function testGetters(): void
    {
        $msg = new HostInvited('guest@example.com', 'host-uuid', 'user-uuid');

        self::assertSame('guest@example.com', $msg->getInviteeEmail());
        self::assertSame('host-uuid', $msg->getHostUuid());
        self::assertSame('user-uuid', $msg->getUserUuid());
    }
}
