<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\AdminBundle\Message;

class HostInvited
{
    public function __construct(private readonly string $inviteeEmail, private readonly string $hostUuid, private readonly string $userUuid)
    {
    }

    public function getInviteeEmail(): string
    {
        return $this->inviteeEmail;
    }

    public function getHostUuid(): string
    {
        return $this->hostUuid;
    }

    public function getUserUuid(): string
    {
        return $this->userUuid;
    }
}
