<div id="stash-count-badge">
    {% if count > 0 %}
        <a href="{{ path('admin_commit_attendances') }}" class="relative inline-flex items-center p-2 text-gray-400 hover:text-gray-500">
            <span class="sr-only">Stash</span>
            <twig:ux:icon name="ph:tray" class="size-6" />
            <span class="absolute top-1.5 right-1.5 block h-4 min-w-4 px-1 rounded-full bg-red-500 text-white text-[10px] font-bold flex items-center justify-center">
                {{ count }}
            </span>
        </a>
    {% endif %}
</div>
