<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\AdminBundle\Components\Edit;

use Symfony\UX\TwigComponent\Attribute\AsTwigComponent;

#[AsTwigComponent('Admin:Edit:Footer', template: '@FerienpassAdmin/components/Edit/Footer.html.twig')]
class Footer
{
    public bool $isDirty = false;
    public bool $isReadonly = false;
    public array $sections = [];
    public ?string $section = null;
    public array $params = [];
    public bool $useLiveAction = false;
    public string $editRoute = 'admin_offers_edit';
    public string $viewRoute = 'admin_offers_proof';
}
