{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}
{% set title = 'organization.title' %}

{% block content %}

    <div class="max-w-3xl mx-auto py-6">

        <h1>{{ 'organization.title'|trans }}</h1>

        <twig:Admin:OrganizationData class="mt-12" host="{{ host }}"/>

    </div>

{% endblock %}
