{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}
{% trans_default_domain 'admin' %}

{% block turbo_frame_attributes %}data-modal-prevent-cancel="true"{% endblock %}

{% block main %}
    <div class="space-y-6">
        <div>
            <h3 class="text-lg font-semibold leading-6 text-gray-900 dark:text-white">
                Termin bearbeiten
            </h3>
        </div>
        <div class="mt-4">
            <twig:Admin:Offer:OfferDateForm :date="date" />
        </div>
    </div>
{% endblock %}
