{% extends "@FerienpassAdmin/layout/base.html.twig" %}

{% block content %}


    {{ form_start(form) }}

    <div class="max-w-7xl mx-auto px-4 sm:px-6 md:px-8 lg:px-12 py-4 sm:py-6 md:py-12 lg:px-16">
        <div class="space-y-10">
            <div class="md:grid md:grid-cols-3 md:gap-6">
                <div class="md:col-span-1">
                    <div class="px-4 sm:px-0">
                        <h3 class="text-lg font-medium leading-6 text-gray-900 dark:text-gray-50">Ihre persönlichen
                            Daten</h3>
                        <div class="mt-1 text-sm leading-5 text-gray-500 dark:text-gray-300">
                            <p>Ihre persönlichen Daten</p>
                        </div>
                    </div>
                </div>
                <div class="mt-5 md:mt-0 md:col-span-2">
                    <div class="shadow overflow-hidden sm:rounded-md">
                        <div class="px-4 py-5 bg-white dark:bg-gray-900 sm:p-6">
                            <div class="space-y-6">
                                {{ form_row(form.firstname) }}
                                {{ form_row(form.lastname) }}
                                {{ form_row(form.userPhone) }}
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="md:grid md:grid-cols-3 md:gap-6">
                <div class="md:col-span-1">
                    <div class="px-4 sm:px-0">
                        <h3 class="text-lg font-medium leading-6 text-gray-900 dark:text-gray-50">Ihre persönlichen
                            Zugangsdaten</h3>
                        <div class="mt-1 text-sm leading-5 text-gray-500 dark:text-gray-300">
                            <p>Dieses werden Ihre Zugangsdaten NACH erfolgreicher Aktivierung sein.</p>
                        </div>
                    </div>
                </div>
                <div class="mt-5 md:mt-0 md:col-span-2">
                    <div class="shadow overflow-hidden sm:rounded-md">
                        <div class="px-4 py-5 bg-white dark:bg-gray-900 sm:p-6">
                            <div class="space-y-6">
                                {{ form_row(form.userEmail) }}
                                {{ form_row(form.userPassword) }}
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="md:grid md:grid-cols-3 md:gap-6">
                <div class="md:col-span-1">
                    <div class="px-4 sm:px-0">
                        <h3 class="text-lg font-medium leading-6 text-gray-900 dark:text-gray-50">Angaben zum
                            Veranstalter</h3>
                        <div class="mt-1 text-sm leading-5 text-gray-500 dark:text-gray-300">
                            <p>Bitte geben Sie Ihre Daten als Veranstalter ein. Diese werden später auf der Webseite
                                veröffentlicht.</p>
                        </div>
                    </div>
                </div>
                <div class="mt-5 md:mt-0 md:col-span-2">
                    <div class="shadow overflow-hidden sm:rounded-md">
                        <div class="px-4 py-5 bg-white dark:bg-gray-900 sm:p-6">
                            <div class="space-y-6">
                                {{ form_row(form.name) }}
                                {{ form_row(form.street) }}
                                {{ form_row(form.postal) }}
                                {{ form_row(form.city) }}
                                {{ form_row(form.email) }}
                                {{ form_row(form.phone) }}
                                {{ form_row(form.website) }}
                                {{ form_row(form.text) }}
                                {{ form_row(form.submit) }}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        {{ form_rest(form) }}

    </div>

    {{ form_end(form) }}

{% endblock %}
