{% trans_default_domain 'admin' %}
{% props title, subtitle = null %}

<div class="flex flex-col gap-y-3 sm:flex-row sm:items-end sm:justify-between py-5 border-b border-gray-200 dark:border-gray-800">
    <div class="min-w-0">
        <h1 class="text-2xl sm:text-[28px] font-extrabold tracking-tight text-gray-900 dark:text-gray-50">{{ title|trans }}</h1>
        {% if subtitle %}
            <p class="mt-1.5 text-sm text-gray-500 dark:text-gray-400 max-w-2xl">{{ subtitle|trans }}</p>
        {% endif %}
        {% block content %}{% endblock %}
    </div>
    {% if block('actions') is not empty %}
        <div class="flex items-center gap-2 shrink-0">
            {% block actions %}{% endblock %}
        </div>
    {% endif %}
</div>
