{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}

{% block main %}

    {{ form_start(form) }}

    <div class="sm:flex sm:items-start">
        <div class="mx-auto flex-shrink-0 flex items-center justify-center h-12 w-12 rounded-full bg-red-100 dark:bg-red-600/70 sm:mx-0 sm:h-10 sm:w-10">
            <span class="block h-6 w-6 text-red-600 dark:text-red-100/90"><twig:ux:icon name="ph:warning" /></span>
        </div>
        <div class="mt-3 text-center sm:mt-0 sm:ml-4 sm:text-left">
            <h3 class="text-lg leading-6 font-medium text-gray-900 dark:text-gray-100"
                id="modal-headline">{{ 'Automtatische Zuteilung' }}</h3>

            <div class="mt-2 space-y-4">
                <p class="text-sm leading-5 text-gray-500 dark:text-gray-300">
                    Sie können die Zuteilung von einem Algorithmus übernehmen lassen, der eine optimale Verteilung
                    bemüht.
                </p>

                <p class="text-sm leading-5 text-gray-500 dark:text-gray-300">
                    Es werden nur unbearbeitete Anmeldungen zugeteilt. Anmeldungen mit Status Zusage/Warteliste/…
                    etc. bleiben unberührt.
                </p>

                <div class="max-w-xs">
                    {{ form_row(form.waitlist) }}
                </div>

                <div>
                    {{ form_widget(form.ignoreMinParticipants) }}
                </div>

                <p class="mt-2 text-sm text-gray-700 dark:text-gray-400 leading-5"><strong class="font-medium">Wollen Sie die automatische
                        Zuteilung jetzt starten?</strong> Sie können die Aktion nicht rückgängig machen.</p>

            </div>
        </div>
    </div>
    <div class="mt-5 sm:mt-4 sm:ml-10 sm:flex sm:pl-4 sm:gap-3">

        <twig:Admin:Button variant="destructive" type="submit" class="w-full justify-center sm:w-auto">Automatische Zuteilung starten</twig:Admin:Button>
        <twig:Admin:Button command="close" commandfor="admin-modal-dialog" class="mt-3 sm:mt-0 w-full justify-center sm:w-auto">Abbrechen</twig:Admin:Button>
    </div>

    {{ form_end(form) }}

{% endblock %}
