<?php

declare(strict_types=1);

namespace Ferienpass\AdminBundle\Tests\Form\CompoundType;

use Ferienpass\AdminBundle\Form\CompoundType\AccessCodesType;
use Ferienpass\AdminBundle\Form\CompoundType\OfferCategoriesType;
use PHPUnit\Framework\TestCase;
use Symfony\UX\LiveComponent\Form\Type\LiveCollectionType;

final class CompoundTypesTest extends TestCase
{
    public function testOfferCategoriesTypeGetParent(): void
    {
        self::assertSame(LiveCollectionType::class, (new OfferCategoriesType())->getParent());
    }

    public function testAccessCodesTypeGetParent(): void
    {
        self::assertSame(LiveCollectionType::class, (new AccessCodesType())->getParent());
    }
}
