{% extends "@FerienpassAdmin/layout/slideOverBase.html.twig" %}

{% trans_default_domain 'admin' %}

{% block main %}

    <div class="mx-auto max-w-3xl">

        <div class="bg-gray-50 dark:bg-gray-800/50 px-4 py-6 sm:px-6 @md:bg-transparent @md:px-0 @md:py-0">
            <div class="space-y-1">
                <h1 class="text-base font-semibold text-gray-900 dark:text-white @md:tracking-tight @md:text-3xl @md:font-extrabold @md:dark:text-gray-50">{{ 'offers.new'|trans }}</h1>
                <p class="text-sm text-gray-500 dark:text-gray-400 @md:mt-1 @md:dark:text-gray-300">Wählen Sie aus, ob Sie mit einer Vorlage starten wollen.</p>
            </div>
        </div>

        <div class="px-4 sm:px-6 @md:px-0">
            <twig:Admin:OfferNewWizard class="mt-6" edition="{{ edition }}" />
        </div>

    </div>

{% endblock %}
