<aside class="border-b border-gray-900/5 py-4 lg:w-76 lg:flex-none lg:border-0 lg:pt-6 lg:pb-12 dark:border-white/10">
    <nav class="flex-none px-4 sm:px-6 lg:px-0">
        <ul role="list" class="flex flex-col gap-y-1">
            {% block items %}{% endblock %}
        </ul>
    </nav>
</aside>
