<div {{ attributes }}>
    <input type="hidden" name="{{ name }}" value="{{ selectedAttachmentUuid }}">

    <div class="mt-4">
        {% include '@FerienpassAdmin/components/Files/_items.html.twig' with {
            contents: { files: this.attachments },
            view: 'grid',
            current: selectedAttachmentUuid ? { path: selectedAttachmentUuid } : null,
            selectAction: 'live#action',
            selectEvent: 'select',
            selectParam: 'uuid'
        } %}
    </div>
</div>
