<div x-data="{}"
     class="bg-gray-300 dark:bg-gray-800 pointer-events-none"
     x-init="$refs.shadow.attachShadow({mode: 'open'}); $refs.shadow.shadowRoot.appendChild( $refs.template.content.cloneNode(true) )">
    <div class="transform scale-90">
        <article x-ref="shadow"></article>
    </div>

    <template x-ref="template">
        <link rel="stylesheet" href="{{ asset ('css/www.tailwind.css') }}">
        {{ importmap('www') }}
        {{ render(controller('Ferienpass\\CmsBundle\\Controller\\Fragment\\OfferDetailsController', { offer: offer.uuid.toRfc4122 })) }}
    </template>

</div>