{% trans_default_domain 'admin' %}
{% set translationPrefix = translationPrefix|default(app.request.get('_route')|default('')|split('_')[1]|default('base')) %}

{% if metadata|default([]) is not empty %}
<div class="border-t border-gray-100 dark:border-gray-700">
    <dl class="divide-y divide-gray-100 dark:divide-gray-800">
        {% for name, value in metadata %}
            <div class="px-4 py-2 sm:grid sm:grid-cols-3 sm:gap-4 sm:px-0">
                <dt class="text-sm font-medium leading-6 text-gray-900 dark:text-gray-100">{{ "#{translationPrefix}.label.#{name}"|trans({}, 'admin') }}</dt>
                <dd class="mt-1 text-sm leading-6 text-gray-700 dark:text-gray-200 sm:col-span-2 sm:mt-0">{{ include(template_from_string(value)) }}</dd>
            </div>
        {% endfor %}
    </dl>
</div>
{% endif %}
