<div{{ attributes }}>
    <div class="overflow-hidden">
        <h3 class="text-base font-semibold leading-6 text-gray-900 dark:text-gray-100" id="modal-title">
            E-Mail-Versand starten
        </h3>
        <div class="mt-2scroll">
            <p class="text-sm text-gray-500 dark:text-gray-400">Sind Sie sicher, dass Sie folgende E-Mail an
                die {{ numberOfEmails }} Empfänger:innen versenden wollen?</p>
        </div>

{#        <div class="mt-2 overflow-x-scroll" id="preview">#}
{#            <template shadowrootmode="open">#}
{#                {% include '@email/mailing.html.twig' with context|merge({content: emailText}) %}#}
{#            </template>#}
{#        </div>#}
    </div>
    <div class="mt-4 sm:flex sm:gap-3">
        <twig:Admin:Button variant="destructive" class="inline-flex w-full justify-center sm:w-auto" data-action="live#emit" data-live-event-param="name(Admin:Mailing)|sendMailing" data-loading="addClass(opacity-50) addAttribute(disabled)">{{ numberOfEmails }} E-Mails versenden</twig:Admin:Button>
        <twig:Admin:Button command="close" commandfor="admin-modal-dialog" class="mt-3 sm:mt-0 inline-flex w-full justify-center sm:w-auto">Abbrechen</twig:Admin:Button>
    </div>
</div>
