{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}
{% set title = 'mailing.title' %}

{% block main %}

    <twig:Admin:PageHeader title="mailing.title" subtitle="Hier können Sie eine Massenmail an alle Teilnehmenden oder Veranstaltenden versenden." />

    <div class="py-6">
        <twig:Admin:Mailing />
    </div>

{% endblock %}
