<a href="{{ uri }}" class="font-medium text-gray-500 dark:text-gray-300 text-sm hover:bg-gray-100 dark:hover:bg-gray-800 hover:text-gray-900 dark:hover:text-gray-100 rounded-md px-1 py-0.5 -mx-1 -my-0.5 transition-colors flex items-center">
    <span class="block h-5 w-5"><twig:ux:icon name="ph:caret-left" /></span>
    {{ 'MSC.backBT'|trans([], 'contao_default') }}
</a>
