{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}

{% block main %}

    <div class="mb-4 @lg:mb-8">
        <twig:Admin:Offer:Header offer="{{ offer }}" detailed="{{ true }}"/>
    </div>

    {% if workflow_has_marked_place(offer, 'completed') %}
        <twig:Admin:Alert class="mt-6 shadow border border-green-700/30" type="confirm"
                          message="Das Angebot ist bereits als „abgeschlossen” markiert."></twig:Admin:Alert>
    {% endif %}

    <div class="mt-6">
        {{ form(form) }}
    </div>

{% endblock %}
