{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}

{% block content %}

    <twig:Admin:PageHeader title="settings.title" subtitle="Systemweite Konfiguration, Integrationen und Stammdaten." />

    <div class="lg:flex lg:gap-x-8">
        <twig:Admin:VerticalNav>
            <twig:block name="items">
                <twig:Admin:VerticalNavItem
                        :name="'general.title'|trans"
                        description="Allgemeine Einstellungen wie Seitentitel, E-Mail und Sprache."
                        href="{{ path('admin_tools_settings_general') }}"
                        icon="ph:gear"
                        :active="app.request.get('_route') == 'admin_tools_settings_general'"
                />
                <twig:Admin:VerticalNavItem
                        :name="'accessCodes.title'|trans"
                        description="Mit Zugangscodes können Teilnehmende exklusiv für bestimmte Zeiträume Angebote buchen."
                        href="{{ path('admin_accessCodes_index') }}"
                        icon="ph:key"
                        :active="app.request.get('_route') starts with 'admin_accessCodes'"
                />
            </twig:block>
        </twig:Admin:VerticalNav>

        <main class="lg:flex-auto lg:pt-6 lg:pb-12 px-4 sm:px-6 lg:px-0">
            <div class="mx-auto max-w-2xl space-y-16 sm:space-y-20 lg:mx-0 lg:max-w-none">

                {% block main %}{% endblock %}

            </div>
        </main>
    </div>

{% endblock %}
