{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}
{% set title = 'Webstatistik' %}

{% block main %}

    <twig:Admin:PageHeader title="Webstatistik" subtitle="Besucherzahlen und Seitenaufrufe der Ferienpass-Website auf einen Blick." />

    {% if iframeSrc %}
        <iframe plausible-embed
                src="{{ iframeSrc }}"
                scrolling="no"
                frameborder="0"
                loading="lazy"
                style="width: 1px; min-width: 100%; height: 1600px; color-scheme: auto;"></iframe>

        <script async src="{{ embedScriptSrc }}"></script>
    {% else %}
        <twig:Admin:Alert type="info" message="Es ist keine Plausible-Statistik konfiguriert. Setzen Sie ferienpass_admin.plausible_shared_link in der Bundle-Konfiguration." />
    {% endif %}

{% endblock %}
