{# @var user \Ferienpass\CoreBundle\Entity\User #}
<div class="flex items-center gap-x-6 bg-yellow-600 dark:bg-yellow-500/20 px-6 py-2.5 sm:px-3.5 sm:before:flex-1">
    <p class="text-sm leading-6 text-white dark:text-yellow-400">
        <strong class="font-semibold">Sie sind angemeldet als {{ user.userIdentifier }}.</strong>
    </p>
    <div class="flex flex-1 justify-end">
        <a href="{{ impersonation_exit_path(path('admin_accounts_index')) }}"
           class="-m-3 p-3 focus-visible:outline-offset-[-4px]">
            <span class="sr-only">Dismiss</span>
            <twig:ux:icon name="ph:x" class="h-5 w-5 text-white" aria-hidden="true" />
        </a>
    </div>
</div>
