{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}
{% trans_default_domain 'admin' %}

{% block main %}
    <div class="space-y-6">
        <div>
            <h3 class="text-lg font-semibold leading-6 text-gray-900 dark:text-white">
                Integration: {{ integration }} konfigurieren
            </h3>
        </div>
        <div class="mt-4">
            {{ form_start(form) }}
                <div class="space-y-4">
                    {{ form_widget(form) }}
                </div>
                <div class="mt-5 sm:mt-6 flex justify-end gap-x-3">
                    <twig:Admin:Button command="close" commandfor="admin-modal-dialog">Abbrechen</twig:Admin:Button>
                    <twig:Admin:Button type="submit" variant="primary">Speichern</twig:Admin:Button>
                </div>
            {{ form_end(form) }}
        </div>
    </div>
{% endblock %}
