<div class="mb-12">
    <h1 is="{{ hl }}" class="text-gray-900 dark:text-gray-50">
        {{ headline }}
    </h1>
    {% if teaser %}
        <div class="mt-3 max-w-2xl text-xl leading-7 text-gray-500 dark:text-gray-300 sm:mt-4">
            {{ teaser|raw }}
        </div>
    {% endif %}
</div>
