{% extends "@FerienpassAdmin/layout/minimal.html.twig" %}

{% block content %}

    <div class="space-y-6">
        <h2 class="font-normal mb-4">Einladung</h2>

        {% if host is defined %}
            <p class="mt-2 mb-4 text-sm leading-5 text-gray-600 dark:text-gray-200 max-w">
                Sie wurden eingeladen, an den Ferienpass-Angeboten von {{ host.name }} mitzuarbeiten.</p>
        {% endif %}

        {% if invitee_email is defined %}
            <twig:Cms:Alert type="info"
                            class="shadow border border-blue-700/30"
                            message="{{ 'Diese Einladung wurde an '~ invitee_email~' geschickt.' }}"/>
        {% endif %}

        {% if form is defined %}
            {{ form(form, { attr: { class: 'space-y-6' } }) }}
        {% endif %}
    </div>

{% endblock %}
