{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}

{% block main %}
        <twig:Admin:Edition:Header edition="{{ edition }}"/>

    <div class="mt-3 max-w-2xl text-base/6 text-gray-500 dark:text-gray-400 sm:mt-4">
        <p>Die Zulosungen sind erst dann gültig, wenn Sie sie mit diesem Tool festschreiben. Höchstwahrscheinlich
            wollen Sie auch direkt die Zulassungsbescheide versenden.
        </p>
    </div>

    <twig:Admin:CommitAttendances edition="{{ edition }}"/>
{% endblock %}
