{% for edition in editions %}
    <a href="{{ path('admin_offers_create_in_edition', { edition: edition.alias }) }}" data-turbo-frame="slideover" aria-labelledby="label-create-offer-{{ edition.id }}" class="group flex cursor-default rounded-xl p-3 select-none focus:outline-hidden aria-selected:bg-gray-100 dark:aria-selected:bg-white/5">
        <div class="flex size-10 flex-none items-center justify-center rounded-lg bg-sky-500">
            <twig:ux:icon name="ph:file" class="size-6 text-white" aria-hidden="true" />
        </div>
        <div class="ml-4 flex-auto">
            <p id="label-create-offer-{{ edition.id }}" class="text-sm font-medium text-gray-700 group-aria-selected:text-gray-900 dark:text-gray-300 dark:group-aria-selected:text-white">Angebot in {{ edition.name }}</p>
            <p class="text-sm text-gray-500 group-aria-selected:text-gray-700 dark:text-gray-400 dark:group-aria-selected:text-gray-300">Erstellen Sie ein neues Angebot für diese Edition.</p>
        </div>
    </a>
{% endfor %}
