<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\AdminBundle\LiveComponent;

class MultiSelectAction
{
    public function __construct(
        public string $name,
        public ?string $route = null,
        public array $routeParameters = [],
        public string $method = 'POST',
        public ?string $turboFrame = null,
    ) {
    }
}
