{% extends "@FerienpassAdmin/layout/list.html.twig" %}
{% trans_default_domain 'admin' %}

{% block list %}
{% component 'Admin:SearchableQueryableList' with {
        qb: qb,
        filterType: filterType,
        routeName: app.current_route,
        routeParameters: app.current_route_parameters|merge(app.request.query.all),
        searchable: searchable|default([]),
        headline: '',
        viewKey: 'admin_payments_receipts',
        viewPathPrefix: '/admin/zahlungen/belege',
        exports: exports|default([]),
        config: config,
    } %}
        {% block page_header %}
            <div class="flex items-center justify-between gap-4 flex-wrap py-5 border-b border-gray-200 dark:border-gray-800 mb-2">
                <twig:Admin:EditionSwitcher
                        :editions="editions|default([])"
                        :selected="selectedEditions|default([])"
                        baseLabel="{{ 'payments.title'|trans({}, 'admin') }}"
                        unscopedRoute="admin_payments_receipts"
                        scopedRoute="admin_payments_receipts" />
            </div>
        {% endblock %}
    {% endcomponent %}
{% endblock %}
