{% set secondary_nav = knp_menu_get('admin_secondary') %}

{% if secondary_nav.hasChildren %}
    <div class="border-t border-gray-200 dark:border-gray-800">
        <div class="max-w-7xl mx-auto px-2 sm:px-4 lg:px-8">
            <div class="border-b border-gray-200 dark:border-gray-800">
                <div class="flex-1 flex overflow-hidden">
                    <nav class="-mb-px flex space-x-8 overflow-x-auto" aria-label="Tabs">
                        {% for item in secondary_nav.children %}
                            <a href="{{ item.uri }}"
                               class="{{ item.current
                               ? 'border-primary-500 text-primary-600 dark:text-primary-400'
                               : 'border-transparent text-gray-500 hover:border-gray-300 hover:text-gray-700 dark:text-gray-400 dark:hover:text-gray-300'
                               }} whitespace-nowrap border-b-2 py-4 text-sm font-medium"
                               {% if item.current %}aria-current="page"{% endif %}>
                                {{ item.label|trans({}, item.getExtra('translation_domain', 'admin')) }}
                            </a>
                        {% endfor %}
                    </nav>
                </div>
            </div>
        </div>
    </div>
{% endif %}
