{% trans_default_domain 'admin' %}

<div class="w-full mb-6">
    <h1 class="text-gray-900 dark:text-gray-50 tracking-tight text-xl font-bold truncate">{{ host.name }}</h1>

    {% include '@FerienpassAdmin/components/_tertiary_nav.html.twig' with { menu: this.menu } only %}
</div>
