<div {{ attributes }}>
    <div class="space-y-4">
        <h3 class="text-lg font-medium">In bestehenden Stash verschieben</h3>
        <p class="text-sm text-gray-500">{{ attendanceIds|length }} Anmeldungen ausgewählt.</p>

        <ul class="divide-y divide-gray-200">
            {% for s in this.stashes %}
                <li class="py-4 flex items-center justify-between">
                    <div>
                        <p class="text-sm font-medium">Stash #{{ s.id }}</p>
                        <p class="text-xs text-gray-500">{{ s.attendances|length }} Anmeldungen</p>
                    </div>
                    <twig:Admin:Button data-action="live#action" data-live-action-param="move" data-live-stash-id-param="{{ s.id }}">Hierhin verschieben</twig:Admin:Button>
                </li>
            {% else %}
                <p class="text-sm text-gray-500">Keine weiteren Stashes vorhanden.</p>
            {% endfor %}
        </ul>
    </div>

    {% if message %}
        <twig:Turbo:Stream:Prepend target="#notifications">
            <twig:Admin:Notification type="success" :title="message" />
        </twig:Turbo:Stream:Prepend>
    {% endif %}
</div>
