<?php

declare(strict_types=1);

namespace Ferienpass\AdminBundle\Tests\Message;

use Ferienpass\AdminBundle\Message\PasswordLinkCreated;
use Ferienpass\AdminBundle\Message\ResetPassword;
use PHPUnit\Framework\TestCase;

final class ResetPasswordTest extends TestCase
{
    public function testGetEmailReturnsEmail(): void
    {
        $msg = new ResetPassword('admin@example.com');

        self::assertSame('admin@example.com', $msg->getEmail());
    }

    public function testPasswordLinkCreatedGetters(): void
    {
        $msg = new PasswordLinkCreated('user-uuid', 'token-abc');

        self::assertSame('user-uuid', $msg->getUserUuid());
        self::assertSame('token-abc', $msg->getToken());
    }
}
