<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\AdminBundle\Controller\Page;

use Ferienpass\CoreBundle\Settings\MailConfigManager;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;

final class Error403Controller extends AbstractController
{
    public function __construct(private readonly MailConfigManager $mailConfigManager)
    {
    }

    public function __invoke(): Response
    {
        return $this->render('@FerienpassAdmin/page/error/403.html.twig', [
            'adminEmail' => $this->mailConfigManager->getAdminEmail(),
            'adminEmailName' => $this->mailConfigManager->getAdminEmailName(),
        ]);
    }
}
