{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}

{% block main %}
    <form action="{{ path('admin_participant_duplicates_tolerate_modal', { uuid1: p1.uuid.toBase58, uuid2: p2.uuid.toBase58 }) }}" method="POST">
        <div class="sm:flex sm:items-start" data-modal-hide-close>
            <div class="mx-auto flex-shrink-0 flex items-center justify-center h-12 w-12 rounded-full bg-yellow-100 dark:bg-yellow-900 sm:mx-0 sm:h-10 sm:w-10">
                <span class="block h-6 w-6 text-yellow-600 dark:text-yellow-300">
                    {{ ux_icon('ph:check') }}
                </span>
            </div>
            <div class="mt-3 text-center sm:mt-0 sm:ml-4 sm:text-left">
                <h3 class="text-lg leading-6 font-medium text-gray-900 dark:text-gray-100" id="modal-headline">Duplikat dulden</h3>
                <div class="mt-2">
                    <p class="text-sm text-gray-500 dark:text-gray-300">
                        Beide Teilnehmende bleiben bestehen, aber Sie können die Anmeldungen von beiden in einer einheitlichen Ansicht sehen.
                        Wählen Sie diese Aktion, wenn es sich um dieselbe Person handelt, die jedoch unter verschiedenen Accounts geführt werden sollen (z. B. getrennte Sorgepflicht).
                    </p>
                </div>
            </div>
        </div>
        <div class="mt-5 sm:mt-4 sm:ml-10 sm:flex sm:pl-4 sm:gap-3">
            <twig:Admin:Button variant="primary" type="submit" class="w-full justify-center bg-yellow-600 hover:bg-yellow-500 focus-visible:outline-yellow-600 sm:w-auto">Dulden bestätigen</twig:Admin:Button>
            <twig:Admin:Button command="close" commandfor="admin-modal-dialog" class="mt-3 sm:mt-0 inline-flex w-full justify-center sm:w-auto">
                Abbrechen
            </twig:Admin:Button>
        </div>
    </form>
{% endblock %}
