{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}

{% block main %}
    <twig:Admin:Edition:Header :edition="edition"/>
    <twig:Admin:Export :edition="edition" />
{% endblock %}
