{% trans_default_domain 'admin' %}

<div class="w-full mb-6">
    <div class="flex flex-wrap items-baseline gap-x-3.5 gap-y-1.5 min-w-0">
        <h1 class="text-gray-900 dark:text-gray-50 tracking-tight text-xl font-bold truncate">{{ edition.name }}</h1>

        {% if edition.archived or edition.online %}
            <div class="hidden @lg:block self-center h-4 w-px bg-gray-300 dark:bg-gray-700"></div>
            {% if edition.archived %}
                <twig:Admin:Badge color="gray" content="{{ 'editions.group.archived'|trans }}" />
            {% else %}
                <twig:Admin:Badge color="green" content="{{ 'editions.group.active'|trans }}" />
            {% endif %}
        {% endif %}
    </div>

    {% include '@FerienpassAdmin/components/_tertiary_nav.html.twig' with { menu: this.menu } only %}
</div>
