{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}

{% block main %}
    <form action="{{ path('admin_participant_duplicates_ignore_modal', { uuid1: p1.uuid.toBase58, uuid2: p2.uuid.toBase58 }) }}" method="POST">
        <div class="sm:flex sm:items-start" data-modal-hide-close>
            <div class="mx-auto flex-shrink-0 flex items-center justify-center h-12 w-12 rounded-full bg-gray-100 dark:bg-gray-800 sm:mx-0 sm:h-10 sm:w-10">
                <span class="block h-6 w-6 text-gray-600 dark:text-gray-300">
                    {{ ux_icon('ph:x') }}
                </span>
            </div>
            <div class="mt-3 text-center sm:mt-0 sm:ml-4 sm:text-left">
                <h3 class="text-lg leading-6 font-medium text-gray-900 dark:text-gray-100" id="modal-headline">Duplikat ignorieren</h3>
                <div class="mt-2">
                    <p class="text-sm text-gray-500 dark:text-gray-300">
                        Dies wird die Teilnehmenden aus der aktuellen Liste der Duplikate entfernen.
                        Wählen Sie diese Aktion, wenn es sich bei <strong>{{ p1.name }}</strong> und <strong>{{ p2.name }}</strong> in Wirklichkeit nicht um dieselbe Person handelt.
                    </p>
                </div>
            </div>
        </div>
        <div class="mt-5 sm:mt-4 sm:ml-10 sm:flex sm:pl-4 sm:gap-3">
            <twig:Admin:Button variant="primary" type="submit" class="w-full justify-center bg-gray-600 hover:bg-gray-500 focus-visible:outline-gray-600 sm:w-auto">Ignorieren bestätigen</twig:Admin:Button>
            <twig:Admin:Button command="close" commandfor="admin-modal-dialog" class="mt-3 sm:mt-0 inline-flex w-full justify-center sm:w-auto">
                Abbrechen
            </twig:Admin:Button>
        </div>
    </form>
{% endblock %}
