<turbo-stream action="update" target="admin-create-palette-frame">
    <template>
        <twig:Turbo:Frame id="attendance-frame">
            <twig:Admin:AddAttendance :offer="offer ?? null" :participant="participant ?? null" />
        </twig:Turbo:Frame>
    </template>
</turbo-stream>
