<div class="max-w-7xl mx-auto py-4 px-2 sm:px-4 lg:px-8">
    <nav aria-label="Fuß-Navigation" class="flex justify-end">
        <a class="text-gray-600 dark:text-gray-300 hover:underline text-sm" href="/datenschutz">Datenschutz</a>
    </nav>
</div>
