{% extends "@FerienpassAdmin/layout/minimal.html.twig" %}
{% trans_default_domain 'admin' %}
{% set title = 'Interner Server-Fehler' %}

{% block content %}
    <div class="mt-6 text-gray-500 dark:text-gray-400">
        <p>Leider ist ein interner Server-Fehler aufgetreten. Wir arbeiten bereits an einer Lösung.</p>
        <div class="mt-10">
            <a href="{{ path('admin_index') }}" class="text-sm/7 font-semibold text-indigo-600 dark:text-indigo-400">
                <span aria-hidden="true">&larr;</span>
                {% if isLoggedIn %}Zum Dashboard{% else %}Zurück zum Login{% endif %}
            </a>
        </div>
    </div>
{% endblock %}
