<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\AdminBundle\Form;

use Ferienpass\CoreBundle\Entity\Offer\OfferInterface;

#[\Attribute(\Attribute::TARGET_CLASS)]
class AsOfferFormType extends AsGuessedFormType
{
    public function __construct(?string $property = null)
    {
        parent::__construct(OfferInterface::class, $property);
    }
}
