{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}
{% set title = 'export.title' %}

{% block main %}

    <twig:Admin:PageHeader title="export.title" subtitle="Ferienpass-Angebote in diverse Formate exportieren: Word, PDF, Excel." />

    <div class="py-6">
        <twig:Admin:Export />
    </div>

{% endblock %}
