<div class="flex-none p-6 text-center">
    <div class="mx-auto size-16 rounded-full bg-primary-100 flex items-center justify-center text-primary-600">
        <twig:ux:icon name="ph:currency-dollar" class="size-8" />
    </div>
    <h2 class="mt-3 font-semibold text-gray-900 dark:text-white">{{ item.receiptNumber|default('Keine Belegnummer') }}</h2>
    <p class="text-sm/6 text-gray-500 dark:text-gray-400">Beleg</p>
</div>
<div class="flex flex-auto flex-col justify-between p-6">
    <dl class="grid grid-cols-1 gap-x-6 gap-y-3 text-sm text-gray-700 dark:text-gray-300">
        <dt class="col-end-1 font-semibold text-gray-900 dark:text-white">Datum</dt>
        <dd>{{ item.createdAt|default ? item.createdAt|date('d.m.Y H:i') : '-' }}</dd>
        <dt class="col-end-1 font-semibold text-gray-900 dark:text-white">Empfänger</dt>
        <dd>{{ item.billingAddress|default('')|split('\n')|first }}</dd>
        <dt class="col-end-1 font-semibold text-gray-900 dark:text-white">Betrag</dt>
        <dd>{{ ((item.totalAmount|default(0))/100)|format_currency('EUR', locale='de') }}</dd>
        <dt class="col-end-1 font-semibold text-gray-900 dark:text-white">Status</dt>
        <dd>
            <twig:Admin:Badge payment="{{ item.status }}" />
        </dd>
    </dl>
    <twig:Admin:Button href="{{ path('admin_payments_receipt', { uuid: item.uuid.toBase58 }) }}" variant="primary" class="mt-6 w-full">Zahlungsbeleg</twig:Admin:Button>
</div>
