{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}

{% block main %}

    <twig:Admin:PageHeader title="Nicht verfügbar" />

    <div class="py-6">
        <twig:Admin:Alert type="error" message="Die Funktion ist nicht vorhanden." />
    </div>

{% endblock %}
