<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\AdminBundle\Components;

use Symfony\UX\TwigComponent\Attribute\AsTwigComponent;

#[AsTwigComponent]
class Notification
{
    public string $type = 'default';
    public string $title = '';
    public string $message = '';
    public ?string $actionTitle = null;
    public ?string $actionLink = null;
    public ?string $primaryActionTitle = null;
    public ?string $primaryActionLink = null;
    public ?string $secondaryActionTitle = null;
    public ?string $secondaryActionLink = null;
    public bool $dismissible = true;
    public ?int $dismissAfter = 7;
}
