"use strict";

import {Controller} from "@hotwired/stimulus";
import {Chart} from "frappe-charts";

export default class extends Controller {
  static values = {
    config: Object,
  };

  connect() {
    new Chart(this.element, this.configValue);
  }
}
