{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}

{% block main %}

    {% if form is defined %}

        <h3 class="text-base font-semibold leading-6 text-gray-900">E-Mail-Adresse wieder anmelden</h3>
        <div class="mt-2 max-w-xl text-sm text-gray-500">
            <p>Der Account ist aktuell auf eigenem Wunsch von E-Mails abgemeldet, das heißt, kann aktuell keine E-Mails
                vom System empfangen, weil die Kontaktaufnahme unerwünscht ist. Auf konkreten Wunsch des/der
                Account-Inhaber:in können Sie das rückgängig machen und die E-Mail wieder freischalten.</p>
        </div>
        <div class="mt-5">
            {{ form_start(form) }}
            <twig:Admin:Button variant="primary" type="submit" class="bg-green-600 hover:bg-green-500 focus-visible:outline-green-500">E-Mail freischalten</twig:Admin:Button>
            {{ form_end(form) }}
        </div>

    {% else %}

        <div>
            <div class="mx-auto flex items-center justify-center h-12 w-12 rounded-full bg-green-100 dark:bg-green-500/10">
                <twig:ux:icon name="ph:check" class="h-6 w-6 text-green-600 dark:text-green-400" />
            </div>
            <div class="mt-3 text-center sm:mt-5">
                <h3 class="text-lg leading-6 font-medium text-gray-900 dark:text-white">Der Account kann wieder E-Mails
                    empfangen</h3>
                <div class="mt-2">
                    <p class="text-sm leading-5 text-gray-500 dark:text-gray-300">Die E-Mail-Adresse {{ item.email }}
                        wurde von der Block-Liste entfernt und kann wieder E-Mails empfangen.</p>
                </div>
            </div>
        </div>

    {% endif %}

{% endblock %}
