{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}
{% set title = 'Seite nicht gefunden' %}

{% block main %}
    <div class="max-w-5xl mx-auto px-4 sm:px-6 md:px-8 lg:px-12 py-4 sm:py-6 md:py-12 lg:px-16 flex items-center justify-center flex-col h-full">
        <div class="flex-1 flex flex-col items-center justify-center text-center px-2 sm:px-4 py-6">
            <h1 class="text-4xl tracking-tight leading-10 font-extrabold text-gray-900 dark:text-white sm:text-4xl sm:leading-none md:text-5xl">
                Seite nicht gefunden
            </h1>
            <p class="mt-3 text-base text-gray-500 dark:text-gray-200 sm:mt-5 sm:text-lg sm:max-w-xl sm:mx-auto md:mt-5 md:text-xl lg:mx-0">
                Die von Ihnen aufgerufene Seite konnte nicht gefunden werden.
            </p>
            <div class="mt-10 flex items-center justify-center gap-x-6">
                <twig:Admin:Button href="{{ path('admin_index') }}" variant="primary">Zum Dashboard</twig:Admin:Button>
                <a href="{{ 'mailto:'~adminEmail }}" class="text-sm font-semibold text-gray-900 dark:text-gray-50">Administrator kontaktieren <span aria-hidden="true">&rarr;</span></a>
            </div>
            <img class="mt-10 sm:mt-16 h-auto w-full max-w-xs" src="{{ asset('images/error404.svg', 'ferienpass_core') }}"
                 alt=""/>
        </div>
    </div>
{% endblock %}
