<div>

    <h2 class="text-base font-semibold leading-6 text-gray-900 dark:text-gray-50">Was passiert gerade?</h2>
    <p class="mt-1 text-sm text-gray-500 dark:text-gray-300">Die Etappen haben einen funktionalen
        Einfluss auf das System. Abhängigkeiten müssen erfüllt sein, um nächste Etappen zu aktivieren.</p>

    {% for element in editions %}

        <div class="mt-2 overflow-hidden"
                {{ stimulus_controller('ferienpass/admin-dashboard-gantt', {
                    tasks: element.tasks,
                }) }}
        >

            <div {{ stimulus_target('ferienpass/admin-dashboard-gantt', 'gantt') }}></div>

        </div>

    {% endfor %}

</div>
