<?php

declare(strict_types=1);

namespace Ferienpass\AdminBundle\Tests\Message;

use Ferienpass\AdminBundle\Message\PasswordLinkCreated;
use PHPUnit\Framework\TestCase;

final class PasswordLinkCreatedTest extends TestCase
{
    public function testGetters(): void
    {
        $msg = new PasswordLinkCreated('user-uuid', 'tok-abc');

        self::assertSame('user-uuid', $msg->getUserUuid());
        self::assertSame('tok-abc', $msg->getToken());
        self::assertNotEmpty($msg->getRelated());
    }
}
