<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\AdminBundle\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;

class PmPaymentConfigType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('pmPaymentAgs', TextType::class, [
                'label' => 'AGS (Amtlicher Gemeindeschlüssel)',
            ])
            ->add('pmPaymentSalt', TextType::class, [
                'label' => 'Salt (Hash Key)',
            ])
            ->add('pmPaymentProcedure', TextType::class, [
                'label' => 'Verfahren (Procedure)',
            ])
        ;
    }
}
