{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% set title = 'Zugriff verweigert' %}

{% block main %}

    <div class="max-w-5xl mx-auto px-4 sm:px-6 md:px-8 lg:px-12 py-4 sm:py-6 md:py-12 lg:px-16 flex items-center justify-center flex-col h-full">

        <div class="flex-1 flex flex-col items-center justify-center text-center px-2 sm:px-4 py-6">
            <h1 class="text-4xl tracking-tight leading-10 font-extrabold text-gray-900 dark:text-white sm:text-4xl sm:leading-none md:text-5xl">
                Zugriff verweigert
            </h1>
            <p class="mt-3 text-base text-gray-500 dark:text-gray-200 sm:mt-5 sm:text-lg sm:max-w-xl sm:mx-auto md:mt-5 md:text-xl lg:mx-0">
                Die Aktion, die Sie durchführen wollen, ist nicht erlaubt.
            </p>
            <p class="mt-1 text-xs text-gray-500 dark:text-gray-200 sm:text-sm sm:max-w-xl sm:mx-auto md:mt-2 md:text-base lg:mx-0">
                Sie können den Fehler beheben, in dem Sie sich abmelden und neu anmelden. Wenn der Fehler bestehen bleibt, kontaktieren Sie bitte den Administrator.
            </p>
            <div class="mt-10 flex items-center justify-center gap-x-6">
                {% if is_granted('IS_IMPERSONATOR') %}
                    <twig:Admin:Button href="{{ impersonation_exit_path(path('admin_accounts_index')) }}" variant="primary" data-turbo="false">Abmelden</twig:Admin:Button>
                {% else %}
                    {# logout is POST-only #}
                    <form action="{{ logout_path('ferienpass_admin') }}" method="post" data-turbo="false">
                        <twig:Admin:Button type="submit" variant="primary">Abmelden</twig:Admin:Button>
                    </form>
                {% endif %}
                <a href="{{ 'mailto:'~adminEmail }}" class="text-sm font-semibold text-gray-900 dark:text-gray-50">Administrator kontaktieren <span aria-hidden="true">&rarr;</span></a>
            </div>
            <img class="mt-10 sm:mt-16 h-auto w-full max-w-xs" src="{{ asset('images/error403.svg', 'ferienpass_core') }}"
                 alt=""/>
        </div>

    </div>

{% endblock %}
