<?php

declare(strict_types=1);

namespace Ferienpass\AdminBundle\Tests\Controller\Page;

use Ferienpass\AdminBundle\Controller\Page\Error404Controller;
use PHPUnit\Framework\TestCase;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

final class Error404ControllerTest extends TestCase
{
    public function testInvokeThrowsNotFound(): void
    {
        $controller = new Error404Controller();

        $this->expectException(NotFoundHttpException::class);

        $controller();
    }
}
