{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}
{% set title = 'outbox.title' %}

{% block main %}

    <twig:Admin:PageHeader title="outbox.title" subtitle="Vom System gesendete Nachrichten — durchsuchbar und filterbar." />

    <div class="py-6">
        <twig:Admin:Outbox />
    </div>

{% endblock %}
