<div class="flex-none p-6 text-center">
    <div class="mx-auto size-16 rounded-full bg-primary-100 flex items-center justify-center text-primary-600">
        <twig:ux:icon name="ph:buildings" class="size-8" />
    </div>
    <h2 class="mt-3 font-semibold text-gray-900 dark:text-white">{{ item.name }}</h2>
    <p class="text-sm/6 text-gray-500 dark:text-gray-400">Veranstaltende</p>
</div>
<div class="flex flex-auto flex-col justify-between p-6">
    <dl class="grid grid-cols-1 gap-x-6 gap-y-3 text-sm text-gray-700 dark:text-gray-300">
        <dt class="col-end-1 font-semibold text-gray-900 dark:text-white">Angebote</dt>
        <dd>{{ item.offers|length }}</dd>
        {% if item.users|default([]) is not empty %}
            <dt class="col-end-1 font-semibold text-gray-900 dark:text-white">Benutzerkonten</dt>
            <dd>{{ item.users|map(u => "#{u.firstname} #{u.lastname}")|join(', ') }}</dd>
        {% endif %}
    </dl>
    <twig:Admin:Button href="{{ path('admin_hosts_edit', {uuid: item.uuid.toBase58}) }}" variant="primary" class="mt-6 w-full">Bearbeiten</twig:Admin:Button>
</div>
