<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\AdminBundle\Form\Filter;

enum Ttl
{
    /** Resets at the next 00:00 wall-clock (in the server's default timezone). */
    case EndOfDay;

    /** Resets at the next :00 wall-clock hour (in the server's default timezone). */
    case TopOfHour;
}
