{% trans_default_domain 'admin' %}

<div class="sm:flex sm:justify-between py-4">

    <div>
        {% block page_headline %}
            {% if headline|default is not empty %}
                <h1 class="text-gray-900 dark:text-gray-50 tracking-tight text-3xl font-extrabold">{{ headline|trans }}</h1>
            {% endif %}
        {% endblock %}
    </div>

    <div class="mt-4 sm:mt-0 flex space-x-3 sm:justify-end">

        {% block headline_actions %}
            {% if createUrl|default(null) is not null %}
                <twig:Admin:Button href="{{ createUrl }}" variant="primary">
                    <span class="flex items-center space-x-1">
                        <span class="size-4"><twig:ux:icon name="ph:plus" /></span>
                        <span>Neu anlegen</span>
                    </span>
                </twig:Admin:Button>
            {% endif %}

        {% endblock %}

    </div>

</div>
