{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}
{% trans_default_domain 'admin' %}

{% block main %}

    <div data-modal-variant="large" class="h-full">
        <twig:Admin:Files storage="{{ storage }}" path="{{ path }}" offerUuid="{{ offer }}" class="h-full" />
    </div>

{% endblock %}