.ts-control{
  border:1px solid #d0d0d0;
  border-radius:3px;
  box-shadow:none;
  box-sizing:border-box;
  display:flex;
  flex-wrap:wrap;
  overflow:hidden;
  padding:8px;
  position:relative;
  width:100%;
  z-index:1
}

.ts-wrapper.multi.has-items .ts-control{
  padding:6px 8px 3px
}

.full .ts-control{
  background-color:#fff
}

.disabled .ts-control,.disabled .ts-control *{
  cursor:default!important
}

.focus .ts-control{
  box-shadow:none
}

.ts-control>*{
  display:inline-block;
  vertical-align:baseline
}

.ts-wrapper.multi .ts-control>div{
  background:#f2f2f2;
  border:0 solid #d0d0d0;
  color:#303030;
  cursor:pointer;
  margin:0 3px 3px 0;
  padding:2px 6px
}

.ts-wrapper.multi .ts-control>div.active{
  background:#e8e8e8;
  border:0 solid #cacaca;
  color:#303030
}

.ts-wrapper.multi.disabled .ts-control>div,.ts-wrapper.multi.disabled .ts-control>div.active{
  background:#fff;
  border:0 solid #fff;
  color:#7d7d7d
}

.ts-control>input{
  background:none!important;
  border:0!important;
  box-shadow:none!important;
  display:inline-block!important;
  flex:1 1 auto;
  line-height:inherit!important;
  margin:0!important;
  max-height:none!important;
  max-width:100%!important;
  min-height:0!important;
  min-width:7rem;
  padding:0!important;
  text-indent:0!important;
  -webkit-user-select:auto!important;
  -moz-user-select:auto!important;
  user-select:auto!important
}

.ts-control>input::-ms-clear{
  display:none
}

.ts-control>input:focus{
  outline:none!important
}

.has-items .ts-control>input{
  margin:0 4px!important
}

.ts-control.rtl{
  text-align:right
}

.ts-control.rtl.single .ts-control:after{
  left:15px;
  right:auto
}

.ts-control.rtl .ts-control>input{
  margin:0 4px 0 -2px!important
}

.disabled .ts-control{
  background-color:#fafafa;
  opacity:.5
}

.input-hidden .ts-control>input{
  left:-10000px;
  opacity:0;
  position:absolute
}

.ts-dropdown{
  background:#fff;
  border:1px solid #d0d0d0;
  border-radius:0 0 3px 3px;
  border-top:0;
  box-shadow:0 1px 3px rgba(0,0,0,.1);
  box-sizing:border-box;
  left:0;
  margin:.25rem 0 0;
  position:absolute;
  top:100%;
  width:100%;
  z-index:10
}

.ts-dropdown [data-selectable]{
  cursor:pointer;
  overflow:hidden
}

.ts-dropdown [data-selectable] .highlight{
  background:rgba(125,168,208,.2);
  border-radius:1px
}

.ts-dropdown .create,.ts-dropdown .no-results,.ts-dropdown .optgroup-header,.ts-dropdown .option{
  padding:5px 8px
}

.ts-dropdown .option,.ts-dropdown [data-disabled],.ts-dropdown [data-disabled] [data-selectable].option{
  cursor:inherit;
  opacity:.5
}

.ts-dropdown [data-selectable].option{
  cursor:pointer;
  opacity:1
}

.ts-dropdown .optgroup:first-child .optgroup-header{
  border-top:0
}

.ts-dropdown .optgroup-header{
  background:#fff;
  color:#303030;
  cursor:default
}

.ts-dropdown .active{
  background-color:#f5fafd;
  color:#495c68
}

.ts-dropdown .active.create{
  color:#495c68
}

.ts-dropdown .create{
  color:rgba(48,48,48,.5)
}

.ts-dropdown .spinner{
  display:inline-block;
  height:30px;
  margin:5px 8px;
  width:30px
}

.ts-dropdown .spinner:after{
  animation:lds-dual-ring 1.2s linear infinite;
  border-color:#d0d0d0 transparent;
  border-radius:50%;
  border-style:solid;
  border-width:5px;
  content:" ";
  display:block;
  height:24px;
  margin:3px;
  width:24px
}

@keyframes lds-dual-ring{
  0%{
    transform:rotate(0deg)
  }

  to{
    transform:rotate(1turn)
  }
}

.ts-dropdown-content{
  max-height:200px;
  overflow:hidden auto;
  scroll-behavior:smooth
}

.ts-wrapper.plugin-drag_drop .ts-dragging{
  color:transparent!important
}

.ts-wrapper.plugin-drag_drop .ts-dragging>*{
  visibility:hidden!important
}

.plugin-checkbox_options:not(.rtl) .option input{
  margin-right:.5rem
}

.plugin-checkbox_options.rtl .option input{
  margin-left:.5rem
}

.plugin-clear_button{
  --ts-pr-clear-button:1em
}

.plugin-clear_button .clear-button{
  background:transparent!important;
  cursor:pointer;
  margin-right:0!important;
  opacity:0;
  position:absolute;
  right:2px;
  top:50%;
  transform:translateY(-50%);
  transition:opacity .5s
}

.plugin-clear_button.form-select .clear-button,.plugin-clear_button.single .clear-button{
  right:max(var(--ts-pr-caret),8px)
}

.plugin-clear_button.focus.has-items .clear-button,.plugin-clear_button:not(.disabled):hover.has-items .clear-button{
  opacity:1
}

.ts-wrapper .dropdown-header{
  background:color-mix(#fff,#d0d0d0,85%);
  border-bottom:1px solid #d0d0d0;
  border-radius:3px 3px 0 0;
  padding:10px 8px;
  position:relative
}

.ts-wrapper .dropdown-header-close{
  color:#303030;
  font-size:20px!important;
  line-height:20px;
  margin-top:-12px;
  opacity:.4;
  position:absolute;
  right:8px;
  top:50%
}

.ts-wrapper .dropdown-header-close:hover{
  color:#000
}

.plugin-dropdown_input.focus.dropdown-active .ts-control{
  border:1px solid #d0d0d0;
  box-shadow:none
}

.plugin-dropdown_input .dropdown-input{
  background:transparent;
  border:solid #d0d0d0;
  border-width:0 0 1px;
  box-shadow:none;
  display:block;
  padding:8px;
  width:100%
}

.plugin-dropdown_input .items-placeholder{
  border:0!important;
  box-shadow:none!important;
  width:100%
}

.plugin-dropdown_input.dropdown-active .items-placeholder,.plugin-dropdown_input.has-items .items-placeholder{
  display:none!important
}

.ts-wrapper.plugin-input_autogrow.has-items .ts-control>input{
  min-width:0
}

.ts-wrapper.plugin-input_autogrow.has-items.focus .ts-control>input{
  flex:none;
  min-width:4px
}

.ts-wrapper.plugin-input_autogrow.has-items.focus .ts-control>input::-moz-placeholder{
  color:transparent
}

.ts-wrapper.plugin-input_autogrow.has-items.focus .ts-control>input::placeholder{
  color:transparent
}

.ts-dropdown.plugin-optgroup_columns .ts-dropdown-content{
  display:flex
}

.ts-dropdown.plugin-optgroup_columns .optgroup{
  border-right:1px solid #f2f2f2;
  border-top:0;
  flex-basis:0;
  flex-grow:1;
  min-width:0
}

.ts-dropdown.plugin-optgroup_columns .optgroup:last-child{
  border-right:0
}

.ts-dropdown.plugin-optgroup_columns .optgroup:before{
  display:none
}

.ts-dropdown.plugin-optgroup_columns .optgroup-header{
  border-top:0
}

.ts-wrapper.plugin-remove_button .item{
  align-items:center;
  display:inline-flex
}

.ts-wrapper.plugin-remove_button .item .remove{
  border-radius:0 2px 2px 0;
  box-sizing:border-box;
  color:inherit;
  display:inline-block;
  padding:0 6px;
  text-decoration:none;
  vertical-align:middle
}

.ts-wrapper.plugin-remove_button .item .remove:hover{
  background:rgba(0,0,0,.05)
}

.ts-wrapper.plugin-remove_button.disabled .item .remove:hover{
  background:none
}

.ts-wrapper.plugin-remove_button .remove-single{
  font-size:23px;
  position:absolute;
  right:0;
  top:0
}

.ts-wrapper.plugin-remove_button:not(.rtl) .item{
  padding-right:0!important
}

.ts-wrapper.plugin-remove_button:not(.rtl) .item .remove{
  border-left:1px solid #d0d0d0;
  margin-left:6px
}

.ts-wrapper.plugin-remove_button:not(.rtl) .item.active .remove{
  border-left-color:#cacaca
}

.ts-wrapper.plugin-remove_button:not(.rtl).disabled .item .remove{
  border-left-color:#fff
}

.ts-wrapper.plugin-remove_button.rtl .item{
  padding-left:0!important
}

.ts-wrapper.plugin-remove_button.rtl .item .remove{
  border-right:1px solid #d0d0d0;
  margin-right:6px
}

.ts-wrapper.plugin-remove_button.rtl .item.active .remove{
  border-right-color:#cacaca
}

.ts-wrapper.plugin-remove_button.rtl.disabled .item .remove{
  border-right-color:#fff
}

:root{
  --ts-pr-clear-button:0;
  --ts-pr-caret:0;
  --ts-pr-min:.75rem
}

.ts-wrapper.single .ts-control,.ts-wrapper.single .ts-control input{
  cursor:pointer
}

.ts-control:not(.rtl){
  padding-right:max(var(--ts-pr-min),var(--ts-pr-clear-button) + var(--ts-pr-caret))!important
}

.ts-control.rtl{
  padding-left:max(var(--ts-pr-min),var(--ts-pr-clear-button) + var(--ts-pr-caret))!important
}

.ts-wrapper{
  position:relative
}

.ts-control,.ts-control input,.ts-dropdown{
  color:#303030;
  font-family:inherit;
  font-size:13px;
  line-height:18px
}

.ts-control,.ts-wrapper.single.input-active .ts-control{
  background:#fff;
  cursor:text
}

.ts-hidden-accessible{
  clip:rect(0 0 0 0)!important;
  border:0!important;
  -webkit-clip-path:inset(50%)!important;
  clip-path:inset(50%)!important;
  overflow:hidden!important;
  padding:0!important;
  position:absolute!important;
  white-space:nowrap!important;
  width:1px!important
}

.ts-control{
  margin-top:0.5rem;
  height:2.25rem;
  width:100%;
  border-radius:0.375rem;
  border-width:1px;
  --tw-border-opacity:1;
  border-color:rgb(209 213 219 / var(--tw-border-opacity));
  padding-top:0.25rem;
  padding-bottom:0.25rem;
  padding-left:0.75rem;
  padding-right:0.75rem;
  --tw-shadow:0 1px 2px 0 rgb(0 0 0 / 0.05);
  --tw-shadow-colored:0 1px 2px 0 var(--tw-shadow-color);
  box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}

.ts-control:focus{
  --tw-border-opacity:1;
  border-color:rgb(99 102 241 / var(--tw-border-opacity));
  outline:2px solid transparent;
  outline-offset:2px;
  --tw-ring-opacity:1;
  --tw-ring-color:rgb(99 102 241 / var(--tw-ring-opacity))
}

@media (min-width: 640px){
  .ts-control{
    font-size:0.875rem;
    line-height:1.5rem
  }
}

.ts-control input{
  margin:0px !important;
  padding-right:1.25rem !important;
  font-size:0.875rem;
  line-height:1.25rem
}

.ts-wrapper.plugin-remove_button .item{
  border-radius:0.375rem
}

.ts-wrapper.multi .ts-control > div{
  margin:0px;
  padding:0px;
  padding-left:0.25rem
}

.ts-wrapper.plugin-remove_button .item .remove{
  border-top-right-radius:0.5rem;
  border-bottom-right-radius:0.5rem;
  border-style:none;
  padding-top:0.25rem;
  padding-bottom:0.25rem;
  font-size:1.125rem;
  line-height:1.75rem;
  line-height:1
}

.ts-dropdown{
  border-radius:0.375rem;
  border-width:1px;
  border-top-width:1px;
  border-style:solid;
  --tw-border-opacity:1;
  border-color:rgb(209 213 219 / var(--tw-border-opacity))
}

.ts-dropdown .option, .ts-dropdown .no-results{
  padding-top:0.5rem;
  padding-bottom:0.5rem;
  padding-left:1rem;
  padding-right:1rem;
  font-size:0.875rem;
  line-height:1.25rem;
  --tw-text-opacity:1;
  color:rgb(17 24 39 / var(--tw-text-opacity))
}

.ts-dropdown [data-selectable].option:first-child{
  border-top-left-radius:0.375rem;
  border-top-right-radius:0.375rem
}

.ts-dropdown [data-selectable].option:last-child{
  border-bottom-right-radius:0.375rem;
  border-bottom-left-radius:0.375rem
}

.ts-dropdown .create:hover, .ts-dropdown .active{
  --tw-bg-opacity:1;
  background-color:rgb(79 70 229 / var(--tw-bg-opacity));
  --tw-text-opacity:1;
  color:rgb(255 255 255 / var(--tw-text-opacity))
}

.ts-dropdown .spinner{
  height:auto;
  width:auto
}

.ts-dropdown .spinner:after{
  margin-top:0px;
  margin-bottom:0px;
  display:inline-block;
  height:1.25rem;
  width:1.25rem;
  border-width:2px;
  padding:0px
}

.ts-wrapper:not(.form-control):not(.form-select).single .ts-control {
  background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 20 20'%3e%3cpath stroke='%236b7280' stroke-linecap='round' stroke-linejoin='round' stroke-width='1.5' d='M6 8l4 4 4-4'/%3e%3c/svg%3e");
  background-position: right 0.5rem center;
  background-repeat: no-repeat;
  background-size: 1.5em 1.5em;
  -webkit-print-color-adjust: exact;
          print-color-adjust: exact;
}
