{% trans_default_domain 'admin' %}

<div {{ attributes.defaults({ class: 'overflow-hidden rounded-xl border border-gray-200 bg-white shadow-sm dark:border-gray-700 dark:bg-gray-800' }) }}>

    <div class="p-6">

        {% if success is not null %}
            <twig:Admin:Alert type="confirm" class="mb-4 shadow border border-green-700/30">
                {{ success|trans }}
            </twig:Admin:Alert>
        {% endif %}

        {{ form_start(form, { attr: {
            'data-model': 'norender|*',
            'data-action': 'live#action:prevent',
            'data-live-action-param': 'submit'
        } }) }}

        <div class="grid grid-cols-2 md:grid-cols-6 gap-x-5 gap-y-4">

            <div class="col-span-2 md:col-span-4">
                {{ form_row(form.oldPassword) }}
            </div>

            <div class="col-span-2 md:col-span-3">
                {{ form_row(form.plainPassword|first) }}
            </div>

            <div class="col-span-2 md:col-span-3">
                {{ form_row(form.plainPassword|last) }}
            </div>

        </div>

        <div class="mt-5 flex">
            {{ form_row(form.submit) }}
        </div>

        {{ form_end(form) }}

    </div>

</div>
