{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}

{% block main %}

    {% if form is defined %}

        <h3 class="text-base font-semibold leading-6 text-gray-900 dark:text-white">Passwort festlegen</h3>
        <div class="mt-2 max-w-xl text-sm text-gray-500 dark:text-gray-200">
            <p>Mit folgender Aktion wird ein neues Passwort generiert und festgelegt. Sollte bereits ein Passwort
                festgelegt sein, wird dies nicht mehr gültig sein.</p>
        </div>
        <div class="mt-5">
            {{ form_start(form) }}
            <twig:Admin:Button variant="primary" type="submit" class="bg-green-600 hover:bg-green-500 focus-visible:outline-green-500">Passwort generieren</twig:Admin:Button>
            {{ form_end(form) }}
        </div>

    {% else %}

        <h3 class="text-base font-semibold leading-6 text-gray-900 dark:text-white">Passwort festlegen</h3>
        <div class="mt-2 max-w-xl text-sm text-gray-500 dark:text-gray-200">
            <p>Das Passwort wurde erfolgreich festgelegt. Bitte teilen Sie dem Accountinhabenden die neuen Zugangsdaten mit.</p>
        </div>
        <div class="mt-5">
            <dl class="text-base text-gray-900 dark:text-white">
                <div class="flex space-x-2 leading-6">
                    <dt class="font-semibold">Anmeldeseite:</dt>
                    {% if item.isMember %}
                        <dd>{{ app.request.schemeAndHttpHost }}</dd>
                    {% else %}
                        <dd>{{ absolute_url(path('admin_index')) }}</dd>
                    {% endif %}
                </div>

                <div class="flex space-x-2 leading-6">
                    <dt class="font-semibold">Benutzername:</dt>
                    <dd>{{ item.email }}</dd>
                </div>

                <div class="flex space-x-2 leading-6">
                    <dt class="font-semibold">Passwort:</dt>
                    <dd>{{ password }}</dd>
                </div>
            </dl>
        </div>

    {% endif %}

{% endblock %}
