<div>

    <h2 class="text-base font-semibold leading-6 text-gray-900 dark:text-gray-50">Was ist gerade so los?</h2>
    <p class="mt-1 text-sm text-gray-500 dark:text-gray-300">Das Schaubild zeigt Ihnen die Anzahl der Anmeldungen pro Tag.</p>

    <div {{ stimulus_controller('ferienpass/admin-chart', { config: {
        type: 'heatmap',
        discreteDomains: 0,
        colors: ["#ebedf0", "#c0ddf9", "#73b3f3", "#3886e1", "#17459e"],
        data: {
            dataPoints: values,
        },
        language: 'de'
    }}) }}></div>

</div>
