{% trans_default_domain 'admin' %}
{% set translationPrefix = app.request.get('_route')|split('_')[1] %}

{% extends "@FerienpassAdmin/layout/edit.html.twig" %}

{% block edit_page_header %}

    <twig:Admin:Account:Header user="{{ item }}"/>

{% endblock %}

{% block edit_form %}

    <twig:Admin:Edit:Account
            class="border-t border-gray-200 dark:border-gray-800 mt-6 pt-6"
            form="{{ form }}"
            formOptions="{{ formOptions }}"
            item="{{ item }}"
            sections="{{ formScreen.sections }}"
            section="{{ section }}"
    />

{% endblock %}
