{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}

{% block main %}

    {% embed '@FerienpassAdmin/fragment/deleteModal.html.twig' with {
        metadata: {
            title: '{{ item.name }}',
            holiday: "{{ item.holiday ? item.holiday.periodBegin|date('d.m.Y') ~ ' - ' ~  item.holiday.periodEnd|date('d.m.Y') : '' }}",
            countOffers: '{{ item.offers|length }}',
            archived: '{{ item.archived ? "ja" : "nein" }}',
        }
    } %}

        {% block content %}
            {% if item.offers|length %}
                <div class="mt-2 flex">
                    <div class="flex-shrink-0">
                        <twig:ux:icon name="ph:warning" class="h-5 w-5 text-yellow-700 dark:text-yellow-500" aria-hidden="true" />
                    </div>
                    <div class="ml-2">
                        <p class="text-sm text-yellow-700 dark:text-yellow-500">
                            <span class="font-semibold">Es werden alle {{ item.offers|length }} Angebote mit jeweiligen
                                Anmeldungen mitgelöscht!</span> Wenn Sie das nicht wollen, verschieben Sie die Angebote
                            vorher in eine andere Saison.
                        </p>
                    </div>
                </div>
            {% endif %}

        {% endblock %}

    {% endembed %}

{% endblock %}
