{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}

{% block main %}

    {% include '@FerienpassAdmin/fragment/deleteModal.html.twig' with {
        metadata: {
            type: '{{ "consent.#{item.type}"|trans({}, "admin") }} {{ item.type == "edition_agreement_letter" ? item.edition.name : "" }}',
            date: '{{ item.signedAt|date("d.m.Y H:i") }}',
            user: '{{ item.user.name }}',
        }
    } %}

{% endblock %}
