{% extends "@FerienpassAdmin/layout/modalBase.html.twig" %}

{% block main %}

    {% embed '@FerienpassAdmin/fragment/deleteModal.html.twig' with {
        metadata: {
            accountRoles: '{{ item.accountRoles|map(r => "accounts.role.#{r}"|trans([], "admin"))|join(", ") }}',
            name: '{{ item.name }}',
            email: '{{ item.email }}',
            participants: '{{ item.participants|map(u => "#{u.name}")|join(", ") }}',
            hosts: '{{ item.hosts|map(u => "#{u.name}")|join(", ") }}'
        }
    } %}

        {% block content %}
            {% if item.participants|length %}
                <div class="mt-2 flex">
                    <div class="flex-shrink-0">
                        <twig:ux:icon name="ph:warning" class="h-5 w-5 text-yellow-700 dark:text-yellow-500" aria-hidden="true" />
                    </div>
                    <div class="ml-2">
                        <p class="text-sm text-yellow-700 dark:text-yellow-500">
                            <span class="font-semibold">Kinder und Anmeldungen werden mitgelöscht!</span> Wenn Sie das
                            nicht
                            wollen, bearbeiten Sie die Kinder und entfernen die Eltern-Zuordnung.
                        </p>
                    </div>
                </div>
            {% endif %}

            {% if item.hosts|length %}
                <div class="mt-2 flex">
                    <div class="flex-shrink-0">
                        <twig:ux:icon name="ph:info" class="h-5 w-5 text-blue-600 dark:text-blue-500" aria-hidden="true" />
                    </div>
                    <div class="ml-2">
                        <p class="text-sm text-blue-700 dark:text-blue-400">
                            Die Veranstalter-Profile bleiben erhalten.
                        </p>
                    </div>
                </div>
            {% endif %}

        {% endblock %}

    {% endembed %}

{% endblock %}
